#
# spec file for package octave-forge-interval
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define octpkg  interval
Name:           octave-forge-%{octpkg}
Version:        1.1.0
Release:        7.1
Summary:        Real-valued interval arithmetic for Octave
License:        GPL-3.0+
Group:          Productivity/Scientific/Math
Url:            http://octave.sourceforge.net
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  mpfr-devel
BuildRequires:  octave-devel
Requires:       octave-cli >= 3.8.2

%description
The interval package for real-valued interval arithmetic allows to
evaluate functions over subsets of their domain.  All results are verified,
because interval computations automatically keep track of any errors.

These concepts can be used to handle uncertainties, estimate arithmetic errors
and produce reliable results.  Also it can be applied to computer-assisted
proofs, constraint programming, and verified computing.

The implementation is based on interval boundaries represented by binary64
numbers and is conforming to IEEE Std 1788-2015, IEEE standard for interval
arithmetic.

This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
sed -i 's/-lgmp/-lgomp/' interval-%{version}/src/Makefile
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Update to version 1.1.0
  * meshgrid, mince: New utility functions to help plotting of
    interval functions
  * linspace: New interval arithmetic function
  * intersect, max, min, union: Allow evaluation as aggregate
    functions within an interval matrix along a common dimension
  * Improvements in the documentation
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Update to version 1.0.0
  * IEEE 1788, the standard for interval arithmetic, was approved on
    June 11.  To mark the occasion, the major version number has been
    raised.
  * All interval constructors have been extended to create interval
    matrices from a single string.  Commas or spaces may be used as a
    column separator (consecutive separators are trimmed).  Semicolon
    and new line characters can be used as a row separator.
  * hdist, idist, sdist, smig: New interval numeric functions
  * User manual: Relicensed under GPL, added examples from the former
    Octave SIMP package, and various minor improvements.
  * Documentation was relicenced to GPL-3.0
  Bugfixes
  * mtimes: Fixed matrix-vector multiplication of decorated intervals
  * Fixed a linking error in mkoctfile that could prevent package
    installation (bug #45280)
* Sun May 31 2015 dmitry_r@opensuse.org
- Update to version 0.2.1
  * plot, plot3: New interval plotting functions. Pay attention to the
    included examples, which can be executed with 'demo @infsup/plot'
    and 'demo @infsup/plot3' respectively.
  * polyval: New interval arithmetic algorithm
  * bisect: New set operation for bisecting algorithms
  * sinrev, cosrev, tanrev, atan2rev1, atan2rev2: Now allow non-scalar
    arguments
  * Simplified licensing: Relicensed parts of the software that were
    not under GPL
  * Updated information for citation of the package
* Mon May  4 2015 dmitry_r@opensuse.org
- Update to version 0.2.0
  * User manual included in the package
  * New utility functions: cat, postpad, prepad, reshape, resize
  * and, or: Removed deprecated functions
  * Improved display output for cell arrays and new function: disp
  * Minor performance improvements (all decorated interval functions,
    horzcat, vertcat)
  * Bugfixes
* Wed Apr  8 2015 dmitry_r@opensuse.org
- Update to version 0.1.5
  * Implicit decoration of bare intervals triggers a warning now and
    can be allowed or forbidden by the user.  Implicit decoration
    of bare interval literals is not affected.
  * newdec: New operation for explicit promotion of bare intervals
    into decorated intervals (without warning).
  * Decorated interval literals with illegal decoration are
    no longer allowed and produce NaIs.
  * hull: In contrast to the union function, the interval constructor
    is no longer considered a set operation and can create intervals
    with a non-trivial decoration.
  * setdiff, setxor: New set operations
  * intersect, union: Renamed set operations; the old function names (and, or)
  are hereby deprecated and are going to be removed in the next release.
  * intervaltotext, intervaltoexact: Decimal fractions no longer omit zero
    before the point, and unnecessary trailing decimal places can be omitted
    more consistently and in more cases than before (also affects console
    output). Improved accuracy and performance with support for interval
    matrices.
* Thu Mar 19 2015 dmitry_r@opensuse.org
- Update to version 0.1.4
  * New interval constructors: hull, midrad
  * New interval arithmetic functions: cbrt, cot, coth, csc, csch,
    dilog, ei, erf, erfc, gamma, gammaln, psi, rsqrt, sec, sech
  * mtimes: Support for fast, less accurate evaluation using BLAS routines
  * mldivide, mrdivide, inv: Improved performance by using faster mtimes
  * infsup, infsupdec: Enabled broadcasting of scalar boundaries
  * rad: May compute mid and rad simultaneously
  * subsref: Access to interval properties using field syntax: x.inf and x.sup
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 0.1.3
